function [train_data, test_data, classes, colors_samples,colors_classifiers] = get_toy_data(visualize)
rng(1)
classes=5;
samples_per_class=500;
sigma=1.0;
num_samples = classes*samples_per_class;

% classes A-E with negative labels
noise_dim = 100;
feature_dim = 2;
dim = noise_dim+feature_dim;

cluster_centers = [2  -4; -3  3; 3   1; -5 -2; -4 -5];
colors_samples = {'og','sr','xb','+m','dy'};
colors_classifiers = {'g','r','b','m','y'};

figure
hold on
title('Training Data')
data = zeros(dim+1, num_samples);
for j=1:classes
    data(:, (j-1)*samples_per_class+1:j*samples_per_class) = ...
        [repmat(cluster_centers(j, :),samples_per_class,1) + randn(samples_per_class,2)*sigma ...
        randn(samples_per_class, noise_dim)*3 ...
        j*ones(samples_per_class, 1)]';
    
    scatter(data(1, (j-1)*samples_per_class+1:j*samples_per_class),...
        data(2, (j-1)*samples_per_class+1:j*samples_per_class),colors_samples{j});
end

% Suffle data
shuffle = randperm(size(data, 2));
data = data(:, shuffle);

% Split data into training and test set
N = num_samples-0.1*num_samples;
train_data = data(:, 1:N);
test_data = data(:, N+1:end);

if (visualize)
    figure;
subplot(1,2,1);
hold on
for j=1:classes
   scatter(train_data(1, train_data(end, :) == j),...
   train_data(2, train_data(end, :) == j),colors_samples{j});
end
axis equal;
title('Training Data');

subplot(1,2,2);
hold on
for j=1:classes
   scatter(test_data(1, test_data(end, :) == j),...
   test_data(2, test_data(end, :) == j),colors_samples{j});
end
axis equal;
title('Test Data');
end

end